==> trilinos-15.1.1.tar.gz: Trilinos-trilinos-release-15-1-1/packages/amesos2/src/Amesos2_ShyLUBasker_FunctionMap.hpp <==
// @HEADER
//
// ***********************************************************************
//
//           Amesos2: Templated Direct Sparse Solver Package
//                  Copyright 2011 Sandia Corporation
//
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of the Corporation nor the names of the
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// Questions? Contact Michael A. Heroux (maherou@sandia.gov)
//
// ***********************************************************************
//
// @HEADER

/**
   \file   Amesos2_Baker_FunctionMap.hpp
   \author Joshua Dennis Booth <jdbooth@sandia.gov>
           Siva Rajamanickam <srajama@sandia.gov>

   \brief  Provides a mechanism to map function calls to the correct Solver
           function based on the scalar type of Matrices and MultiVectors
*/

#ifndef AMESOS2_SHYLUBASKER_FUNCTIONMAP_HPP
#define AMESOS2_SHYLUBASKER_FUNCTIONMAP_HPP

#ifdef HAVE_TEUCHOS_COMPLEX
#include <complex>
#endif

#include "Amesos2_FunctionMap.hpp"
#include "Amesos2_ShyLUBasker_TypeMap.hpp"

//#include "shylubasker_decl.hpp"
//#include "shylubasker_def.hpp"
//#include "shylubasker_trilinos_decl.hpp"

namespace Amesos2 {

  /* ==================== Specializations ====================
   *
   * \cond ShyLUBasker_function_specializations
   */

  /**
   * \brief Pass function calls to ShyLUBasker based on data type.

   */
#ifdef HAVE_TEUCHOS_COMPLEX
  template <>
  struct FunctionMap<ShyLUBasker,Kokkos::complex<double>>
  {
    static std::complex<double> * convert_scalar(Kokkos::complex<double> * pData) {
      return reinterpret_cast<std::complex<double> *>(pData);
    }
  };

#endif // HAVE_TEUCHOS_COMPLEX

  // if not specialized, then assume generic conversion is fine
  template <typename scalar_t>
  struct FunctionMap<ShyLUBasker,scalar_t>
  {
    static scalar_t * convert_scalar(scalar_t * pData) {
      return pData; // no conversion necessary
    }
  };


  /* \endcond ShyLUBasker_function_specializations */


} // end namespace Amesos2

#endif  // AMESOS2_SHYLUBASKER_FUNCTIONMAP_HPP

==> trilinos_16.1.0.orig.tar.gz: Trilinos-trilinos-release-16-1-0/packages/amesos2/src/Amesos2_ShyLUBasker_FunctionMap.hpp <==
// @HEADER
// *****************************************************************************
//           Amesos2: Templated Direct Sparse Solver Package
//
// Copyright 2011 NTESS and the Amesos2 contributors.
// SPDX-License-Identifier: BSD-3-Clause
// *****************************************************************************
// @HEADER

/**
   \file   Amesos2_Baker_FunctionMap.hpp
   \author Joshua Dennis Booth <jdbooth@sandia.gov>
           Siva Rajamanickam <srajama@sandia.gov>

   \brief  Provides a mechanism to map function calls to the correct Solver
           function based on the scalar type of Matrices and MultiVectors
*/

#ifndef AMESOS2_SHYLUBASKER_FUNCTIONMAP_HPP
#define AMESOS2_SHYLUBASKER_FUNCTIONMAP_HPP

#ifdef HAVE_TEUCHOS_COMPLEX
#include <complex>
#endif

#include "Amesos2_FunctionMap.hpp"
#include "Amesos2_ShyLUBasker_TypeMap.hpp"

//#include "shylubasker_decl.hpp"
//#include "shylubasker_def.hpp"
//#include "shylubasker_trilinos_decl.hpp"

namespace Amesos2 {

  /* ==================== Specializations ====================
   *
   * \cond ShyLUBasker_function_specializations
   */

  /**
   * \brief Pass function calls to ShyLUBasker based on data type.

   */
#ifdef HAVE_TEUCHOS_INST_COMPLEX_DOUBLE
  template <>
  struct FunctionMap<ShyLUBasker,Kokkos::complex<double>>
  {
    static std::complex<double> * convert_scalar(Kokkos::complex<double> * pData) {
      return reinterpret_cast<std::complex<double> *>(pData);
    }
  };
#endif // HAVE_TEUCHOS_COMPLEX_DOUBLE

#ifdef HAVE_TEUCHOS_INST_COMPLEX_FLOAT
  template <>
  struct FunctionMap<ShyLUBasker,Kokkos::complex<float>>
  {
    static std::complex<float> * convert_scalar(Kokkos::complex<float> * pData) {
      return reinterpret_cast<std::complex<float> *>(pData);
    }
  };
#endif // HAVE_TEUCHOS_INST_COMPLEX_FLOAT

  // if not specialized, then assume generic conversion is fine
  template <typename scalar_t>
  struct FunctionMap<ShyLUBasker,scalar_t>
  {
    static scalar_t * convert_scalar(scalar_t * pData) {
      return pData; // no conversion necessary
    }
  };


  /* \endcond ShyLUBasker_function_specializations */


} // end namespace Amesos2

#endif  // AMESOS2_SHYLUBASKER_FUNCTIONMAP_HPP
